#!/usr/bin/env python
# -*- coding: utf-8 -*-
# 
# Copyright 2016 The Aerospace Corporation.
# 
# This is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
# 
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this software; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
# 

try:
    from enthought.traits.api import *
    from enthought.traits.ui.api import *
    import enthought.traits.ui
except ImportError:
    from traits.api import *
    from traitsui.api import *

from location_data import *

# To get a scrollable checklist, adapted from
# http://stackoverflow.com/questions/33435586/scrollable-group-with-a-list-using-traitsui
class ScrollableChecklist(HasTraits):
    list_of_items = ListStr
    selected = ListStr(multi_select=True,
                       editor=CheckListEditor(name='list_of_items', format_str='%s'),
                       section="Product Filters", config_name="States")
    traits_view = View(UCustom('selected'), scrollable=True)

class BasicConfigurationsTab(HasTraits):
    product_filter = List(editor=SetEditor(
        values = SORTED_PRODUCT_LIST,
        can_move_all = False,
        left_column_title = 'Available Products',
        right_column_title = 'Selected Products',
    ), section="Product Filters", config_name="Products")
    office_filter = List(editor=SetEditor(
        values = SORTED_OFFICE_LIST,
        can_move_all = False,
        left_column_title = 'Available Offices',
        right_column_title = 'Selected Offices',
    ), section="Product Filters", config_name="Offices")
    state_filter = Instance(ScrollableChecklist)
    counties_list = ListStr(editor=ListStrEditor(multi_select=True, 
                                                 editable=False, 
                                                 selected='counties_filter'))
    counties_filter = ListStr(section="Product Filters", config_name="Counties")

    traits_view = View(
        Group(
            HGroup(
                VGroup(
                    UItem('product_filter'),
                    UItem('office_filter')
                ),
                VGroup(
                    Label('<h3>State/Region</h3>'),
                    UCustom('state_filter'),
                    Label('<h3>County</h3>'),
                    UReadonly('counties_list')
                ),
            ),
        ),
        resizable=True
    )
    
    state_abbrev = Property(Set(Str))
    product_abbrev = Property(Set(Str))
    office_abbrev = Property(Set(Str))

    def __init__(self):
        super(BasicConfigurationsTab, self).__init__()
        self.state_filter = ScrollableChecklist(list_of_items=SORTED_STATE_LIST)

    @on_trait_change('state_filter.selected')
    def _update_counties(self, new):
        # concat a bunch of county lists to get new one
        self.counties_list = sum((STATE_NAME_TO_COUNTY_LIST[x] 
                                    for x in self.state_filter.selected), [])

    # grab abbreviations according to filters
    @property_depends_on('state_filter.selected')
    def _get_state_abbrev(self):
        return [STATE_MAP[x].abbrev for x in self.state_filter.selected]
    
    @property_depends_on('product_filter')
    def _get_product_abbrev(self):
        return [PRODUCT_MAP[x].abbrev for x in self.product_filter]
        
    @property_depends_on('office_filter')
    def _get_office_abbrev(self):
        return [WFOSITE_MAP[x].abbrev for x in self.office_filter]
        
    # for testing    
    #@on_trait_change('counties_list, counties_filter')
    #def _print_len(self, name, new): print name, len(new)
            
if __name__ == "__main__":
    BasicConfigurationsTab().configure_traits()
    
